abacusai.database_connector_column — AbacusAI documentation

# `abacusai.database_connector_column`

## Module Contents

### Classes

`DatabaseConnectorColumn` | A schema description for a column from a database connector

class abacusai.database_connector_column.DatabaseConnectorColumn(client, name=None, externalDataType=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  A schema description for a column from a database connector

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - name (str) – The unique name of the column.

    - externalDataType (str) – The data type of column in the external database system.

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict